<?php
namespace BPACCDNNamespaceAccordion;

define('BPACCDN_ACCORDION_PUBLIC_ASSETS_ALL', plugin_dir_url(__FILE__) . 'assets/public');
define('BPACCDN_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE', plugin_dir_url(__FILE__) . 'assets/admin');
class BPACCDNAccordionCreator {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bpaccdn_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bpaccdn_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bpaccdn_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bpaccdn_accordion_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bpaccdn-accordion.php' );
	}

	public function bpaccdn_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files(); 

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BPACCDNAccordionCreatoR() );
	}

	// Register Category
	function bpaccdn_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bpaccdn-blog-post-accordions-category',
			[
				'title' => esc_html__( 'Blog Post Accordions', 'blog-post-accordions' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bpaccdn_all_assets_for_the_public(){
		wp_enqueue_script( 'bpaccdn_accordion_main_js', 'https://bwd-elementor-addons-pro.netlify.app/blog-post-accordions/bpaccdn-main.js', array('jquery'), '2.1', true );
		$all_css_js_file = array(
            'bpaccdn_accordion_font' => array('bpaccdn_path_define_with_accordion'=>'https://bwd-elementor-addons-pro.netlify.app/blog-post-accordions/bpaccdn-main.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bpaccdn_path_define_with_accordion'], null, '2.1', 'all');
        }
		wp_enqueue_style( 'bpaccdn-font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.0/css/all.min.css', null, '2.1', 'all' );
	}
	public function bpaccdn_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bpaccdn_accordion_admin_main_css' => array('bpaccdn_path_admin_define'=>BPACCDN_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bpaccdn_path_admin_define'], null, '2.1', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bpaccdn_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bpaccdn_all_assets_for_elementor_editor_admin']);

		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bpaccdn_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bpaccdn_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bpaccdn_admin_editor_scripts' ] );
	}
}

// Instantiate Plugin Class
BPACCDNAccordionCreator::instance();
